meataxe: Library for computing with modular representations
===========================================================

Description
-----------

SharedMeatAxe 1.0 is an autotoolized shared library version of C MeatAxe
2.4.24, a set of programs for computing with modular representations.
The package comprises a shared library "libmtx", as well as several
executables.

See http://users.minet.uni-jena.de/~king/SharedMeatAxe/ for the package
documentation.

Licence
-------

The Shared Meat-Axe is free software: you can redistribute it and/or
modify it under the terms of the GNU General Public License as published
by the Free Software Foundation, either version 2 of the License, or (at
your option) any later version. See the file COPYING.


Upstream contact
----------------

-  Simon King <simon.king@uni-jena.de>
